# Rapid Build Helper
[![Python application](https://github.com/jszymonek/rapidbuild/actions/workflows/python-app.yml/badge.svg)](https://github.com/jszymonek/rapidbuild/actions/workflows/python-app.yml)

Helper script for building C++ projects.
